//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------
 
    /*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************
	*/


	// This example uses the OpenNetCF.NET.dll Referenced Assembly
	// make sure to include that as a referenced assembly if you
	// copy this code.

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
	using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
	using OpenNETCF.Net.NetworkInformation;		// Needed for TCP socket info.

    public partial class VNCDetection
    {
		// Flag to make sure that the initialization only gets executed once.
		private bool VNCDetectionStarted = false;
		
		// Create new timer object, used for periodically port check.
		private Timer m_timer = new Timer();
		
		// Start check, execute this only once, on screen opened of the first screen.
		public void StartCheck()
		{
			// Make sure that the VNC port check only is started once.
			if(!VNCDetectionStarted)			 // If never started before
			{
				m_timer.Interval = 1000;		 // This is the port check interval [ms]
				m_timer.Tick += TimerTick;
				m_timer.Enabled = true;
				VNCDetectionStarted = true;		 // Set flag for singel shot execution
			}		
		}
		
		// Handle timer ticks, execute port check
		private void TimerTick(System.Object sender, System.EventArgs e)
		{
			CheckIfVNCPortisOpen(5900);			// This is the VNC port to check (default is 5900)
		}
		
		// Swap high and low byte in an integer, converts Intel <-> Motorola format.
		private int byteswap(int n) //swap low and high byte, required to get correct port number
		{
			return ((n & 0xFF) << 8) | ((n & 0xFF00) >> 8);
		}
		
		// Check if VNC port is open, gets port, sets the VncActive tag
		public void CheckIfVNCPortisOpen(int port)
		{
			bool foundPort = false;			
			IPGlobalProperties ipProperties = IPGlobalProperties.GetIPGlobalProperties();
			TcpConnectionInformation[] tcpConnections = ipProperties.GetActiveTcpConnections();
			foreach (TcpConnectionInformation info in tcpConnections)
				if( (byteswap(info.LocalEndPoint.Port) == port) && 
					(info.State.ToString() == "Established") )
					{
						Globals.Tags.VncActive.Value = true;	// Set tag if port connection is established
						foundPort = true;
					}							
			
			if(!foundPort)
				Globals.Tags.VncActive.Value = false;			// If no port is found, reset tag
		}
    }
}
